@@ -217,7 +217,7 @@ void AnnotationViewport::hoverLeaveEvent(QHoverEvent *event)
 
 void AnnotationViewport::mousePressEvent(QMouseEvent *event)
 {
-    if (shouldIgnoreInput() || event->buttons() & ~acceptedMouseButtons()) {
+    if (shouldIgnoreInput() || event->buttons() & ~acceptedMouseButtons() || event->buttons() == Qt::NoButton) {
         QQuickItem::mousePressEvent(event);
         return;
     }
@@ -250,7 +250,7 @@ void AnnotationViewport::mousePressEvent(QMouseEvent *event)
 
 void AnnotationViewport::mouseMoveEvent(QMouseEvent *event)
 {
-    if (shouldIgnoreInput() || event->buttons() & ~acceptedMouseButtons()) {
+    if (shouldIgnoreInput() || event->buttons() & ~acceptedMouseButtons() || event->buttons() == Qt::NoButton) {
         QQuickItem::mouseMoveEvent(event);
         return;
     }
@@ -286,7 +286,7 @@ void AnnotationViewport::mouseMoveEvent(QMouseEvent *event)
 
 void AnnotationViewport::mouseReleaseEvent(QMouseEvent *event)
 {
-    if (shouldIgnoreInput() || event->buttons() & ~acceptedMouseButtons()) {
+    if (shouldIgnoreInput() || event->buttons() & ~acceptedMouseButtons() || event->buttons() == Qt::NoButton) {
         QQuickItem::mouseReleaseEvent(event);
         return;
     }
