@@ -745,6 +745,8 @@ void SpectacleCore::takeNewScreenshot(ImagePlatform::GrabMode grabMode, int time
     m_delayAnimation->setDuration(timeout);
     m_delayAnimation->start();
 
+    // skip minimize animation.
+    SpectacleWindow::setVisibilityForAll(QWindow::Hidden);
     SpectacleWindow::setVisibilityForAll(QWindow::Minimized);
 }
 
@@ -765,6 +767,11 @@ void SpectacleCore::cancelScreenshot()
     m_delayAnimation->stop();
     if (currentTime > 0) {
         SpectacleWindow::setTitleForAll(SpectacleWindow::Previous);
+    } else if (!ViewerWindow::instance()) {
+        initViewerWindow(ViewerWindow::Image);
+        ViewerWindow::instance()->setVisible(true);
+    } else if (ViewerWindow::instance()) {
+        Q_EMIT allDone();
     }
 }
 
@@ -1051,7 +1058,7 @@ void SpectacleCore::initCaptureWindows(CaptureWindow::Mode mode)
     deleteWindows();
 
     if (mode == CaptureWindow::Video) {
-        LayerShellQt::Shell::useLayerShell;
+        LayerShellQt::Shell::useLayerShell();
     }
 
     // Allow the window to be transparent. Used for video recording UI.
@@ -1166,6 +1173,7 @@ QString SpectacleCore::timeFromMilliseconds(qint64 milliseconds) const
 void SpectacleCore::activateAction(const QString &actionName, const QVariant &parameter)
 {
     Q_UNUSED(parameter)
+    m_startMode = StartMode::DBus;
     if (actionName == ShortcutActions::self()->fullScreenAction()->objectName()) {
         takeNewScreenshot(CaptureModeModel::AllScreens, 0);
     } else if (actionName == ShortcutActions::self()->currentScreenAction()->objectName()) {
